@@ -45,14 +45,15 @@
 #include "score.h"
 #include "cursors.h"
 
-const char *dataFileExt = ".png";
-const char *defImageFileName = "puzzle0.jpg";
-
 KSlidePuzzle::KSlidePuzzle(QWidget *parent, const char *name,
   const tOpt opt) : QWidget(parent, name), state(0), options(opt)
 {
-	QString str;
-   KConfig *config = kapp->config();
+  QString str;
+  
+  dataFileExt = ".png";
+  defImageFileName = "puzzle0.jpg";
+
+  KConfig *config = kapp->config();
   config->setGroup("Options");
   if(config->readNumEntry("BackgroundColor",0)==0)
   {
@@ -88,7 +89,12 @@ KSlidePuzzle::KSlidePuzzle(QWidget *parent, const char *name,
 		else
 			break;
 	}
-  kdDebug()<<QString("Found %1 levels").arg(maxlevel)<<endl;
+ kdDebug()<<QString("Found %1 levels in %2").arg(maxlevel).arg(imagepath)<<endl;
+ if(maxlevel==0)
+ {
+   KMessageBox::error(0, "None levels founds ! Check the installation.");
+   return;
+ }
   srand(time(0));
   puz.prevImage = "";
   tempFileName = "";
@@ -101,7 +107,7 @@ KSlidePuzzle::KSlidePuzzle(QWidget *parent, const char *name,
 	currenthints=0;
 	gamelevel=3;
   puz.prevMousePos = QCursor::pos();
-  puz.path = imagepath.latin1();
+  puz.path = imagepath;
   puz.mode = 1;                // default mode is classical game with 4x4 tiles
   puz.size = puz.scrambling = 0;
   setFixedSize(scn.frameSize + 2 * scn.puzOffset, scn.frameSize +
@@ -707,28 +713,28 @@ bool KSlidePuzzle::toggleRandomMissingTile()
 
 QString KSlidePuzzle::getFullPicPath(const char *file)
 {
-  tempFileName = (QString(puz.path) + "/pics/" + file);
+  tempFileName = (puz.path + "/pics/" + file);
   kdDebug()<<QString("getFullPicPath=%1").arg(tempFileName)<<endl;
   return tempFileName;
 }
 
-const char* KSlidePuzzle::getFullSoundPath(const char *file)
+QString KSlidePuzzle::getFullSoundPath(const char *file)
 {
   delete tempFileName;
-  return tempFileName = (QString(puz.path) + "/sounds/" + file).latin1();
+  return tempFileName = (puz.path + "/sounds/" + file).latin1();
 }
 
-const char* KSlidePuzzle::getDataFileName(const tOpt file)
+QString KSlidePuzzle::getDataFileName(const tOpt file)
 {
   switch (file) {
     case fnFrame:
-      return getFullPicPath(QString(scn.frameFileName) + dataFileExt);
+      return getFullPicPath(scn.frameFileName + dataFileExt);
     case fnFrameMask:
-      return getFullPicPath(QString(scn.frameFileName) + 'm' + dataFileExt);
+      return getFullPicPath(scn.frameFileName + 'm' + dataFileExt);
     case fnTiles:
-      return getFullPicPath(QString(scn.tilesFileName) + dataFileExt);
+      return getFullPicPath(scn.tilesFileName + dataFileExt);
     case fnTilesMask:
-      return getFullPicPath(QString(scn.tilesFileName) + 'm' + dataFileExt);
+      return getFullPicPath(scn.tilesFileName + 'm' + dataFileExt);
     default:
       return 0;
   }
@@ -922,9 +928,9 @@ void KSlidePuzzle::setMask(int mask){
 	QString str,str1;
 	QString imagename;
 	str="frame"+QString::number(mask);
-	scn. frameFileName=str.latin1();
+	scn. frameFileName=str;
 	str1="tiles"+QString::number(mask);
-	scn.tilesFileName=str1.latin1();
+	scn.tilesFileName=str1;
 
 		imagename=imagename.sprintf("pics/puzzle%i.jpg",level);
 	imagename=imagepath+imagename;
